@@ -1,10 +1,10 @@
+from __future__ import absolute_import
+
 from pytest_sherlock.sherlock import Sherlock
 
 
 def pytest_addoption(parser):
-    group = parser.getgroup(
-        "sherlock",
-        "Try to find coupled tests")
+    group = parser.getgroup("sherlock", "Try to find coupled tests")
     group.addoption(
         "--flaky-test",
         action="store",
@@ -23,5 +23,5 @@ def pytest_configure(config):
 
 
 def pytest_report_teststatus(report):
-    if report.outcome == 'flaky':
-        return 'flaky', 'F', ('FLAKY', {'yellow': True})
+    if report.outcome == "flaky":
+        return "flaky", "F", ("FLAKY", {"yellow": True})
